<?php
if ( ! defined( 'ABSPATH' ) ) exit;
/**
* Admin System Report Class
* It gives information about the website
*/
class Eos_wi_Admin_System_Report {
	public static function output() {
		add_filter( 'load_textdomain_mofile', 'eos_wi_load_translation_file',99,2 ); //loads plugin translation files
		load_plugin_textdomain( 'eos-wi', FALSE,EOS_wi_PLUGIN_DIR . '/languages/' );
		echo '<div class="wrap eos">';
		self::get_wp_environment_box();
		self::get_server_environment_box();
		self::get_active_plugins_box();
		self::get_theme_box();
		self::add_content_box();
		self::add_sitehealth_box();
		self::add_user_agent_box();
		self::add_debug_report_box();
		echo '</div>';
	}
	public static function get_wp_environment_box(){
		?>
    <div class="eos-widget-full top">
      <div class="eos-widget settings-box">
        <p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'WordPress Environment', 'eos-wi' ); ?></p>
        <div class="eos-list">
          <ul>
            <li>
                <p><?php esc_html_e( 'Home URL', 'eos-wi' ); ?>: <strong><?php echo esc_url( home_url() ); ?></strong></p>
            </li>
            <li>
                <p><?php esc_html_e( 'Wordpress Version', 'eos-wi' ); ?>: <strong><?php echo esc_html( get_bloginfo( 'version' ) ); ?></strong></p>
            </li>
            <li>
                <p><?php esc_html_e( 'Wordpress Multisite', 'eos-wi' ); ?>: <strong><?php if ( is_multisite() ) { esc_html_e( 'Yes','eos-wi' ); } else { esc_html_e( 'No','eos-wi' ); } ?></strong></p>
            </li>
            <li>
                <p><?php esc_html_e( 'Wordpress Debug Mode', 'eos-wi' ); ?>: <strong><?php echo defined( 'WP_DEBUG' ) && esc_html( WP_DEBUG ) ? esc_html__( 'Yes','eos-wi' ) : esc_html__( 'No','eos-wi' ); ?></strong></p>
            </li>
          </ul>
        </div>
      </div>
    </div>
    <?php
	}
	public static function get_server_environment_box() {
		global $wpdb;
		$host_name = function_exists( 'gethostname' ) ? gethostname() : false;
		?>
    <div class="eos-widget-full top">
        <div class="eos-widget settings-box">
            <p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'Server Environment', 'eos-wi' ); ?></p>
            <div class="eos-list">
                <ul>
									<li>
                    <p><?php esc_html_e( 'PHP Version', 'eos-wi' ); ?>: <strong><?php
										// Check if phpversion function exists.
										if ( function_exists( 'phpversion' ) ) {
											$php_version = phpversion();
											if ( version_compare( $php_version, '7.3', '<' ) ) {
												echo '<mark class="error">' . sprintf( esc_html__( '%s - We recommend a minimum PHP version of 7.3.', 'eos-wi' ), esc_html( $php_version ) ) . '</mark>';
											} else {
												echo '<mark class="yes">' . esc_html( $php_version ) . '</mark>';
											}
										} else {
											esc_html_e( "Couldn't determine PHP version because phpversion() doesn't exist.", 'eos-wi' );
										}
												?></strong></p>
                    </li>
                  <li>
                    <p><?php esc_html_e( 'MySQL Version', 'eos-wi' ); ?>: <strong><?php
										/** @global wpdb $wpdb */
										global $wpdb;
										echo $wpdb->db_version();
										?></strong>
										</p>
                  </li>
                  <li>
										<?php if( isset( $_SERVER['SERVER_SOFTWARE'] ) ){ ?>
                    <p><?php echo esc_html( sprintf( __( 'Server software: %s', 'eos-wi' ),$_SERVER['SERVER_SOFTWARE'] ) ); ?></p>
										<?php } ?>
                  </li>
                </ul>
            </div>
        </div>
    </div>
    <?php
	}
	public static function get_active_plugins_box() {
		$mu_plugins = wp_get_mu_plugins();
		$active_plugins = (array) get_option( 'active_plugins', array() );
		?>
		<div class="eos-widget-full top">
			<div class="eos-widget settings-box">
				<p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'Must Use Plugins', 'eos-wi' ); ?></p>
				<div class="eos-list">
					<ul>
					<?php
					foreach( $mu_plugins as $mu_plugin ) {
						?>
						<li><?php echo basename( $mu_plugin ); ?></li>
					<?php } ?>
					</ul>
                </div>
            </div>
        </div>
		<div class="eos-widget-full top">
			<div class="eos-widget settings-box">
				<p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'Active Plugins', 'eos-wi' ); ?></p>
				<div class="eos-list">
					<ul>
					<?php
					$n = 0;
					$plugsN = count( $active_plugins );
					foreach( $active_plugins as $plugin ) {
						$plugin_data = @get_plugin_data( WP_PLUGIN_DIR . '/' . $plugin );
						$version_string = '';
						if ( ! empty( $plugin_data['Name'] ) ) {
							$plugin_name = esc_html( $plugin_data['Name'] );
						}
						if ( ! empty( $version_data['version'] ) && version_compare( $version_data['version'], $plugin_data['Version'], '>' ) ) {
							$version_string = ' &ndash; <strong style="color:red;">' . esc_html( sprintf( _x( '%s is available', 'Version info', 'eos-wi' ), $version_data['version'] ) ) . '</strong>';
						}
						$suffix = $n + 1 < $plugsN ? '; ' : '';
						?>
						<li><?php echo $plugin_name.' '.esc_html( $plugin_data['Version'] ) . $version_string . $suffix; ?></li>
						<?php
						++$n;
					}
					?>
					</ul>
                </div>
            </div>
        </div>
		<?php
	}
	public static function get_theme_box() {
		include_once( ABSPATH . 'wp-admin/includes/theme-install.php' );
		$active_theme = wp_get_theme();
		// @codingStandardsIgnoreStart
		$theme_version = $active_theme->Version;
		$theme_template = $active_theme->Template;
		// @codingStandardsIgnoreEnd
		?>
        <div class="eos-widget-full top">
            <div class="eos-widget settings-box">
                <p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'Current Theme', 'eos-wi' ); ?></p>
                <div class="eos-list">
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'Theme', 'eos-wi' ); ?>: <strong><?php echo esc_html( $active_theme ); ?></strong></p>
                        </li>
                        <li>
                            <p><?php esc_html_e( 'Theme Version', 'eos-wi' ); ?>: <strong><?php echo esc_html( $theme_version ); ?></strong></p>
                        </li>
                        <li>
                            <p><?php esc_html_e( 'Child Theme', 'eos-wi' ); ?>: <strong><?php
									echo is_child_theme() ? '<mark class="yes">'.esc_html__( 'Yes','eos-wi' ).'</mark>' : esc_html__( 'No','eos-wi' ); ?></strong></p>
                        </li>
                        <?php
						if ( is_child_theme() ) :
							$parent_theme = wp_get_theme( $theme_template );
							?>
                            <li>
                                <p><?php esc_html_e( 'Parent Theme', 'eos-wi' ); ?>: <strong><?php echo esc_html( $parent_theme ); ?></strong></p>
                            </li>
						<?php endif; ?>
                    </ul>
                </div>
            </div>
        </div>
        <?php
	}
	public static function add_content_box() {
		$post_types = get_post_types();
		$post_types_queryable = get_post_types( array( 'publicly_queryable' => true ) );
		$pages = get_posts( array( 'posts_per_page' => -1,'post_type' => 'page' ) );
		$blog_posts = get_posts( array( 'posts_per_page' => -1,'post_type' => 'post' ) );
		$posts = get_posts( array( 'posts_per_page' => -1,'post_type' => $post_types ) );
	?>
	<div class="eos-widget-full top">
		<div class="eos-widget settings-box">
			<p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'Content', 'eos-wi' ); ?></p>
				<div class="eos-list">
					<ul>
						<li>
							<p><?php printf( esc_html__( 'Number of Post Types %s', 'eos-wi' ),count( $post_types ) ); ?></p>
							<p><?php printf( esc_html__( 'Queryable Post Types %s', 'eos-wi' ),count( $post_types_queryable ) ); ?></p>
							<p><?php printf( esc_html__( 'Number of Pages: %s', 'eos-wi' ),count( $pages ) ); ?></p>
							<p><?php printf( esc_html__( 'Number of Blog Posts: %s', 'eos-wi' ),count( $blog_posts) ); ?></p>
							<p><?php printf( esc_html__( 'Total Number of posts (any type): %s', 'eos-wi' ),count( $posts) ); ?></p>
						</li>
				</ul>
			</div>
		</div>
	</div>
	<?php
	}
	public static function add_sitehealth_box() {
		require_once ABSPATH.'/wp-admin/includes/class-wp-site-health.php';
		$site_health = get_transient( 'health-check-site-status-result' );
		if( !$site_health ) return;
		$site_health = json_decode( sanitize_text_field( $site_health ) );
	?>
	<div class="eos-widget-full top">
		<div class="eos-widget settings-box">
			<p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'Site Health', 'eos-wi' ); ?></p>
				<div class="eos-list">
					<ul>
						<li>
						<?php  foreach( $site_health as $k => $v ){ ?>
						<p><?php echo esc_html( $k ).': '.esc_html( $v ); ?></p>
						<?php } ?>
						</li>
					</ul>
			</div>
		</div>
	</div>
	<?php
	}
	public static function add_user_agent_box() {
	?>
    <div class="eos-widget-full top">
      <div class="eos-widget settings-box">
        <p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'User Agent', 'eos-wi' ); ?></p>
        <div class="eos-list">
	        <ul>
            <li>
              <p><strong id="eos-user-agent"></strong></p>
            </li>
					</ul>
				</div>
			</div>
		</div>
	<?php
	}
	public static function add_debug_report_box() {
		?>
    <div class="eos-widget-full top">
      <div class="eos-widget">
        <p class="eos-label" style="font-size:30px;"><?php esc_html_e( 'Copy System Report for Support', 'eos-wi' ); ?></p>
        <p class="eos-description">
          <div id="eos-debug-report">
            <textarea style="width:100%" rows="20" readonly="readonly"></textarea>
            <p class="submit"><button id="copy-for-support" class="button-primary" href="#" ><?php esc_html_e( 'Copy for Support', 'eos-wi' ); ?></button></p>
          </div>
        </p>
      </div>
    </div>
    <?php
	}
}
